@@ -653,7 +653,7 @@ class Base(Controller):
 
 
     @ex(
-        help='Manage TODOs using Google Keep',
+        help='Manage TODOs using Asana',
         arguments=[
             (['action'],{
                 "help" : "One of {add, ls, dn}",
@@ -663,10 +663,10 @@ class Base(Controller):
                 "help": "Text of the TODO",
                 "action": "store"
             }),
-            # (['-l'],{
-            #     "help": "Length of time in hours this is expected to take",
-            #     "action": "store"
-            # }),
+            (['-l'],{
+                "help": "Length of time in days this is expected to take",
+                "action": "store"
+            }),
             (['-p'],{
                 "help" : "Project id. Daily is 0",
                 "action" : 'store'
@@ -682,22 +682,25 @@ class Base(Controller):
         ]
     )
     def td(self):
-        from ..ext.asana import add_todo, asana_list_todos, done_todo
+        from ..ext.asana import add_todo, asana_list_todos, done_todo, fix_past_due
         project = int(self.app.pargs.p or 0)
 
         if self.app.pargs.action=='add':
-            add_todo(self.app.pargs.t, project)
+            add_todo(self.app.pargs.t, self.app.pargs.l, project)
         elif self.app.pargs.action=='ls':
-            asana_list_todos(self.app.pargs.f or True,
-                       self.app.pargs.p)
+            asana_list_todos(
+                self.app.pargs.p,
+                self.app.pargs.f,)
         elif self.app.pargs.action=='dn':
             done_todo(self.app.pargs.i)
+        elif self.app.pargs.action=='fix':
+            fix_past_due(self.app.pargs.p)
 
         else:
             raise NotImplemented("Action must be one of {add, ls, dn}")
 
     @ex(
-        help='Manage TODOs using Google Keep',
+        help='(Deprecated) Manage TODOs using Google Keep',
         arguments=[
             (['action'],{
                 "help" : "One of {add, ls, dn}",
