@@ -101,7 +101,7 @@ def add_todo(task_text, expected_duration, project_id=0):
         # 'projects': [workspace_id]
     }
     
-    print(posting, data)
+    print("posting", data)
     result = client.tasks.create_in_workspace(workspace_id, data)
 
     print(json.dumps(result, indent=4))
